@@ -12,6 +12,7 @@ matlab <- function() {
     assign("mode", pracma::Mode, envir = .GlobalEnv)
     assign("norm", pracma::Norm, envir = .GlobalEnv)
     assign("poly", pracma::Poly, envir = .GlobalEnv)
+    assign("rank", pracma::Rank, envir = .GlobalEnv)
     assign("real", pracma::Real, envir = .GlobalEnv)
     assign("reshape", pracma::Reshape, envir = .GlobalEnv)
     assign("strtrim", pracma::strTrim, envir = .GlobalEnv)
@@ -19,5 +20,7 @@ matlab <- function() {
     # assign("", pracma::, envir = .GlobalEnv)
     makeActiveBinding("ans", function() .Last.value, .GlobalEnv)
     makeActiveBinding("who", ls, .GlobalEnv)
+    makeActiveBinding("tic", tic, .GlobalEnv)
+    makeActiveBinding("toc", toc, .GlobalEnv)
     invisible(NULL)
 }
